#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import os
import errno
import re


def createFolderIfNotExist(path):
    try:
        os.makedirs(path)
    except OSError as exception:
        if exception.errno != errno.EEXIST:
            raise


def getInternationalizedNumber(number):
    if not number:
        return "Unknown"

    if number.startswith("0"):
        return number.replace("0", "+49", 1)
    else:
        return number


def getFilename(mydir, mysms):
    if mysms[0]["DateTime"]:
        return mysms[0]["DateTime"].strftime("%Y-%m-%d-%Hh%Mm%Ss")

    # no date available so calculate unknown number
    myfiles = os.listdir(mydir)

    nextitem = 0
    for i in myfiles:
        match = re.match("^Unknown-([0-9]*)", i)
        if match and int(match.group(1)) > nextitem:
            nextitem = int(match.group(1))

    return "Unknown-" + str(nextitem + 1)


def saveSMS(mysms, all_contacts):
    my_number = getInternationalizedNumber(mysms[0]["Number"])

    try:
        mydir = all_contacts[my_number]
    except KeyError:
        mydir = my_number

    createFolderIfNotExist(mydir)

    myfile = getFilename(mydir, mysms)

    with open(os.path.join(mydir, myfile), "a") as handle:
        for i in mysms:
            handle.write(i["Text"].encode("UTF-8"))
        handle.write(u"\n".encode("UTF-8"))


def getContacts(state_machine):

    # Get all contacts
    remaining = state_machine.GetMemoryStatus(Type="SM")["Used"]
    contacts = dict()

    start = True

    try:
        while remaining > 0:
            if start:
                entry = state_machine.GetNextMemory(Start=True, Type="SM")
                start = False
            else:
                entry = state_machine.GetNextMemory(
                    Location=entry["Location"], Type="SM"
                )
                remaining = remaining - 1

            numbers = list()
            for entry in entry["Entries"]:
                if entry["Type"] == "Text_FirstName":
                    name = entry["Value"]
                else:
                    numbers.append(getInternationalizedNumber(entry["Value"]))

            for number in numbers:
                contacts[number] = name

    except gammu.ERR_EMPTY:
        # error is raised if memory is empty (this induces wrong reported
        # memory status)
        print('Failed to read contacts!')

    return contacts


def getAndDeleteAllSMS(state_machine):
    # Read SMS memory status ...
    memory = state_machine.GetSMSStatus()
    # ... and calculate number of messages
    remaining = memory["SIMUsed"] + memory["PhoneUsed"]

    # Get all sms
    start = True
    entries = list()

    try:
        while remaining > 0:
            if start:
                entry = state_machine.GetNextSMS(Folder=0, Start=True)
                start = False
            else:
                entry = state_machine.GetNextSMS(
                    Folder=0, Location=entry[0]["Location"]
                )

            remaining = remaining - 1
            entries.append(entry)

            # delete retrieved sms
            state_machine.DeleteSMS(Folder=0, Location=entry[0]["Location"])

    except gammu.ERR_EMPTY:
        # error is raised if memory is empty (this induces wrong reported
        # memory status)
        print('Failed to read messages!')

    # Link all SMS when there are concatenated messages
    entries = gammu.LinkSMS(entries)

    return entries


def main():
    # Get all contacts
    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()
    contacts = getContacts(state_machine)
    state_machine.Terminate()

    # Get all sms
    # why in two steps? ERR_TIMOUT is raised without closing the connection
    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()
    messages = getAndDeleteAllSMS(state_machine)
    state_machine.Terminate()

    for message in messages:
        saveSMS(message, contacts)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import time
import collections

# Whether be a bit more verbose
VERBOSE = False


def verbose_print(text):
    if VERBOSE:
        print(text)


def reply_test(message):
    if message['Number'] == '999':
        # No reply to this number
        return None
    return 'Reply to {0}'.format(message['Text'])


# Reply function, first element is matching string, second can be:
#  - string = fixed string will be sent as reply
#  - function = function will be called with SMS data and it's result will be
#    sent
#  - None = no reply
REPLIES = [
    ('1/1 www:', 'This is test'),
    ('1/2 www:', reply_test),
    ('2/2 www:', None),
]


def Callback(state_machine, callback_type, data):
    verbose_print('Received incoming event type {0}, data:'.format(callback_type))
    if callback_type != 'SMS':
        print('Unsupported event!')
    if 'Number' not in data:
        data = state_machine.GetSMS(data['Folder'], data['Location'])[0]
    verbose_print(data)

    for reply in REPLIES:
        if data['Text'].startswith(reply[0]):
            if isinstance(reply[1], collections.Callable):
                response = reply[1](data)
            else:
                response = reply[1]

            if response is not None:
                message = {
                    'Text': response,
                    'SMSC': {'Location': 1},
                    'Number': data['Number']
                }
                verbose_print(message)
                state_machine.SendSMS(message)
            else:
                verbose_print('No reply!')
            break


def main():
    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()
    state_machine.SetIncomingCallback(Callback)
    try:
        state_machine.SetIncomingSMS()
    except gammu.ERR_NOTSUPPORTED:
        print('Your phone does not support incoming SMS notifications!')

# We need to keep communication with phone to get notifications
    print('Press Ctrl+C to interrupt')
    while 1:
        time.sleep(1)
        status = state_machine.GetBatteryCharge()
        print('Battery is at {0:d}%'.format(status['BatteryPercent']))


if __name__ == '__main__':
    main()



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
import gammu.worker
from .test_dummy import DummyTest


WORKER_EXPECT = [
    ('Init', None, 'ERR_NONE', 100),
    ('GetManufacturer', 'Gammu', 'ERR_NONE', 100),
    ('GetSIMIMSI', '994299429942994', 'ERR_NONE', 100),
    ('GetIMEI', '999999999999999', 'ERR_NONE', 100),
    ('GetOriginalIMEI', '666666666666666', 'ERR_NONE', 100),
    ('GetManufactureMonth', 'April', 'ERR_NONE', 100),
    ('GetProductCode', 'DUMMY-001', 'ERR_NONE', 100),
    ('GetHardware', 'FOO DUMMY BAR', 'ERR_NONE', 100),
    ('CustomGetInfo', ('unknown', 'Dummy'), 'ERR_NONE', 50),
    (
        'CustomGetInfo',
        {
            'BatteryVoltage': 4200,
            'PhoneTemperature': 22,
            'BatteryTemperature': 22,
            'ChargeState': 'BatteryConnected',
            'ChargeVoltage': 4200,
            'BatteryCapacity': 2000,
            'BatteryPercent': 100,
            'ChargeCurrent': 0,
            'PhoneCurrent': 500
        },
        'ERR_NONE',
        100
    ),
    (
        'GetMemory',
        {
            'MemoryType': 'SM',
            'Location': 1,
            'Entries': [
                {
                    'AddError': 1,
                    'Type': 'Text_Name',
                    'Location': 'Unknown',
                    'Value': 'firstname lastname'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test1'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test2'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test3'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test4'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test5'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test6'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test7'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test8'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test9'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test10'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test11'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test12'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test13'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test14'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test15'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test16'
                }
            ]
        },
        'ERR_NONE',
        100
    ),
    (
        'CustomGetAllMemory',
        {
            'MemoryType': 'SM',
            'Location': 1,
            'Entries': [
                {
                    'AddError': 1,
                    'Type': 'Text_Name',
                    'Location': 'Unknown',
                    'Value': 'firstname lastname'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test1'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test2'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test3'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test4'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test5'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test6'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test7'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test8'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test9'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test10'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test11'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test12'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test13'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test14'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test15'
                },
                {
                    'AddError': 1,
                    'Type': 'Text_Note',
                    'Location': 'Unknown',
                    'Value': 'Test16'
                }
            ]
        },
        'ERR_NONE',
        20
    ),
    ('CustomGetAllMemory', None, 'ERR_EMPTY', 40),
    ('CustomGetAllMemory', None, 'ERR_EMPTY', 60),
    ('CustomGetAllMemory', None, 'ERR_EMPTY', 80),
    ('CustomGetAllMemory', None, 'ERR_EMPTY', 100),
    (
        'GetSMSC',
        {
            'DefaultNumber': '',
            'Format': 'Text',
            'Number': '123456',
            'Validity': 'NA',
            'Location': 1,
            'Name': 'Default'
        },
        'ERR_NONE',
        100
    ),
    ('Terminate', None, 'ERR_NONE', 100)
]


class WorkerDummyTest(DummyTest):
    results = []

    def callback(self, name, result, error, percents):
        self.results.append((name, result, error, percents))

    def test_worker(self):
        self.results = []
        worker = gammu.worker.GammuWorker(self.callback)
        worker.configure(self.get_statemachine().GetConfig())
        # We can directly invoke commands
        worker.enqueue('GetManufacturer')
        worker.enqueue('GetSIMIMSI')
        worker.enqueue('GetIMEI')
        worker.enqueue('GetOriginalIMEI')
        worker.enqueue('GetManufactureMonth')
        worker.enqueue('GetProductCode')
        worker.enqueue('GetHardware')
        worker.enqueue('GetDateTime')
        # We can create compound tasks
        worker.enqueue('CustomGetInfo', commands=[
            'GetModel',
            'GetBatteryCharge'
        ])
        # We can pass parameters
        worker.enqueue('GetMemory', ('SM', 1))
        # We can create compound tasks with parameters:
        worker.enqueue('CustomGetAllMemory', commands=[
            ('GetMemory', ('SM', 1)),
            ('GetMemory', ('SM', 2)),
            ('GetMemory', ('SM', 3)),
            ('GetMemory', ('SM', 4)),
            ('GetMemory', ('SM', 5))
        ])
        worker.initiate()
        # We can also pass commands with named parameters
        worker.enqueue('GetSMSC', {'Location': 1})
        worker.terminate()

        # Remove GetDateTime from comparing as the value changes
        for i in range(len(self.results)):
            if self.results[i][0] == 'GetDateTime':
                self.assertEqual(self.results[i][2], 'ERR_NONE')
                self.assertEqual(self.results[i][3], 100)
                del self.results[i]
                break

        self.maxDiff = None
        self.assertEqual(WORKER_EXPECT, self.results)

    def test_incoming(self):
        self.check_incoming_call()
        self.results = []
        self._called = False
        worker = gammu.worker.GammuWorker(self.callback)
        worker.configure(self.get_statemachine().GetConfig())
        worker.initiate()
        worker.enqueue('SetIncomingCallback', (self.call_callback, ))
        worker.enqueue('SetIncomingCall')
        self.fake_incoming_call()
        worker.terminate()
        self.assertTrue(self._called)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Matthias Blaesing <matthias.blaesing@rwth-aachen.de>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
This file should provide me with a test frame for the filesystem
functions. It can't be run automatically, but you should be able
to decide, wheather the output looks sensible

BEWARE - the test WILL TOUCH AND WRITE FILESYSTEM!!

I asume you call the script from the directory were it lays and
have the grafic there and you have write permission there and that
there is a file called cgi.jpg to be used as test file

READY:
- DeleteFile
- AddFilePart
- GetFilePart
- GetNextRootFolder
- GetNextFileFolder
- GetFolderListing
- SetFileAttributes
- DeleteFolder
- GetFileSystemStatus
- AddFolder
"""

from __future__ import print_function
import gammu
import os
import datetime
import sys
import argparse


def main():
    parser = argparse.ArgumentParser(usage="usage: %(prog)s [options]")

    parser.add_argument("-c", "--config",
                        action="store", type=str,
                        dest="config", default=None,
                        help="Config file path")
    parser.add_argument("-f", "--folder",
                        action="store", type=str,
                        dest="folder", default=None,
                        help="Folder to be used for testing")
    parser.add_argument("-t", "--test-file",
                        action="store", type=str,
                        dest="testfile", default="./data/cgi.jpg",
                        help="Local file to be used for testing")
    args = parser.parse_args()

    if args.folder is None:
        print("You have to select folder where testing will be done!")
        print("And even better, you should read the script before you run it.")
        sys.exit(1)

    if not os.path.exists(args.testfile):
        print("You have to select file which will be used for testing!")
        sys.exit(1)

    state_machine = gammu.StateMachine()
    if args.config is not None:
        state_machine.ReadConfig(Filename=args.config)
    else:
        state_machine.ReadConfig()
    state_machine.Init()

    # Check GetFileSystemStatus
    print("Expection: Info about filesystem usage")
    try:
        fs_info = state_machine.GetFileSystemStatus()
        fs_info["Total"] = fs_info["Free"] + fs_info["Used"]
        print("Used: {Used:d}, Free: {Free:d}, Total: {Total:d}".format(**fs_info))
    except gammu.ERR_NOTSUPPORTED:
        print("You will have to live without this knowledge")

    # Check DeleteFile
    print("\n\nExpection: Deleting cgi.jpg from memorycard")
    try:
        state_machine.DeleteFile(unicode(args.folder + "/cgi.jpg"))
    except gammu.ERR_FILENOTEXIST:
        print("Oh well - we copy it now ;-) (You SHOULD read this)")

    # Check AddFilePart
    print("\n\nExpection: Put cgi.jpg onto Memorycard on phone")
    file_handle = open(args.testfile, "rb")
    file_stat = os.stat(args.testfile)
    ttime = datetime.datetime.fromtimestamp(file_stat[8])
    file_f = {
        "ID_FullName": args.folder,
        "Name": u"cgi.jpg",
        "Modified": ttime,
        "Folder": 0,
        "Level": 1,
        "Used": file_stat[6],
        "Buffer": file_handle.read(),
        "Type": "Other",
        "Protected": 0,
        "ReadOnly": 0,
        "Hidden": 0,
        "System": 0,
        "Handle": 0,
        "Pos": 0,
        "Finished": 0
    }
    while not file_f["Finished"]:
        file_f = state_machine.AddFilePart(file_f)

    # Check GetFilePart
    print(
        "\n\nExpection: Get cgi.jpg from memorycard and write it as test.jpg"
    )
    with open('./test.jpg', 'wb') as handle:
        file_f = {
            "ID_FullName": args.folder + "/cgi.jpg",
            "Finished": 0
        }
        while not file_f["Finished"]:
            file_f = state_machine.GetFilePart(file_f)
        handle.write(file_f["Buffer"])
        handle.flush()

    # Check correct transfer
    print("\n\nExpection: test.jpg and cgi.jpg to be the same")
    f1 = open(args.testfile, "rb")
    f2 = open("./test.jpg", "rb")
    if f1.read() == f2.read():
        print("Same files")
    else:
        print("Files differ!")

    os.remove("./test.jpg")

    # Check GetNextRootFolder
    print("\n\nExpection: Root Folder List")
    try:
        file_obj = state_machine.GetNextRootFolder(u"")
        while 1:
            print(file_obj["ID_FullName"] + " - " + file_obj["Name"])
            try:
                file_obj = state_machine.GetNextRootFolder(
                    file_obj["ID_FullName"]
                )
            except gammu.ERR_EMPTY:
                break
    except gammu.ERR_NOTSUPPORTED:
        print("Not supported...")

    # Check GetNextFileFolder
    print("\n\nExpection: Info for a file of the phone (cgi.jpg)")
    file_f = state_machine.GetNextFileFolder(1)
    while 1:
        if file_f["Name"] != "cgi.jpg":
            file_f = state_machine.GetNextFileFolder(0)
        else:
            attribute = ""
            if file_f["Protected"]:
                attribute = attribute + "P"
            if file_f["ReadOnly"]:
                attribute = attribute + "R"
            if file_f["Hidden"]:
                attribute = attribute + "H"
            if file_f["System"]:
                attribute = attribute + "S"
            print((
                "ID:         " + file_f["ID_FullName"] + "\n" +
                "Name:       " + file_f["Name"] + "\n" +
                "Folder:     " + str(file_f["Folder"]) + "\n" +
                "Used:       " + str(file_f["Used"]) + "\n" +
                "Modified:   " + file_f["Modified"].strftime("%x %X") + "\n" +
                "Type:       " + file_f["Type"] + "\n" +
                "Level:      " + str(file_f["Level"]) + "\n" +
                "Attribute:  " + attribute
            ))

            break

    # Check SetFileAttributes
    # Protected is spared, as my mobile nokia 6230i says it's unsupported
    print(
        "\n\nExpection: Modifying attributes "
        "(readonly=1, protected=0, system=1, hidden=1)"
    )
    state_machine.SetFileAttributes(
        unicode(args.folder + "/cgi.jpg"), 1, 0, 1, 1
    )

    # Check GetFolderListing
    print("\n\nExpection: Listing of cgi.jpg's properties")
    file_f = state_machine.GetFolderListing(unicode(args.folder), 1)
    while 1:
        if file_f["Name"] != "cgi.jpg":
            file_f = state_machine.GetFolderListing(unicode(args.folder), 0)
        else:
            attribute = ""
            if file_f["Protected"]:
                attribute = attribute + "P"
            if file_f["ReadOnly"]:
                attribute = attribute + "R"
            if file_f["Hidden"]:
                attribute = attribute + "H"
            if file_f["System"]:
                attribute = attribute + "S"
            print((
                "ID:         " + file_f["ID_FullName"] + "\n" +
                "Name:       " + file_f["Name"] + "\n" +
                "Folder:     " + str(file_f["Folder"]) + "\n" +
                "Used:       " + str(file_f["Used"]) + "\n" +
                "Modified:   " + file_f["Modified"].strftime("%x %X") + "\n" +
                "Type:       " + file_f["Type"] + "\n" +
                "Level:      " + str(file_f["Level"]) + "\n" +
                "Attribute:  " + attribute
            ))

            break

    # Check DeleteFile
    print("\n\nExpection: Deletion of cgi.jpg from memorycard")
    try:
        state_machine.DeleteFile(unicode(args.folder + "cgi.jpg"))
        print("Deleted")
    except gammu.ERR_FILENOTEXIST:
        print("Something is wrong ...")

    # Check AddFolder
    print("\n\nExpection: Creation of a folder on the memorycard \"42alpha\"")
    state_machine.AddFolder(unicode(args.folder), u"42alpha")

    # Check GetFolderListing again *wired*
    print("\n\nExpection: Print properties of newly created folder")
    file_f = state_machine.GetFolderListing(unicode(args.folder), 1)
    while 1:
        if file_f["Name"] != "42alpha":
            file_f = state_machine.GetFolderListing(unicode(args.folder), 0)
        else:
            attribute = ""
            if file_f["Protected"]:
                attribute = attribute + "P"
            if file_f["ReadOnly"]:
                attribute = attribute + "R"
            if file_f["Hidden"]:
                attribute = attribute + "H"
            if file_f["System"]:
                attribute = attribute + "S"
            print((
                "ID:         " + file_f["ID_FullName"] + "\n" +
                "Name:       " + file_f["Name"] + "\n" +
                "Folder:     " + str(file_f["Folder"]) + "\n" +
                "Used:       " + str(file_f["Used"]) + "\n" +
                "Modified:   " + file_f["Modified"].strftime("%x %X") + "\n" +
                "Type:       " + file_f["Type"] + "\n" +
                "Level:      " + str(file_f["Level"]) + "\n" +
                "Attribute:  " + attribute
            ))

            break

    # Check DeleteFolder
    print("\n\nExpection: Deletion of previously created folder \"42alpha\"")
    state_machine.DeleteFolder(unicode(args.folder + "/42alpha"))


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""Sample script to show how to send long (multipart) SMS"""

from __future__ import print_function
import gammu
import sys

# Create object for talking with phone
state_machine = gammu.StateMachine()

# Optionally load config file as defined by first parameter
if len(sys.argv) > 2:
    # Read the configuration from given file
    state_machine.ReadConfig(Filename=sys.argv[1])
    # Remove file name from args list
    del sys.argv[1]
else:
    # Read the configuration (~/.gammurc)
    state_machine.ReadConfig()

# Check parameters
if len(sys.argv) != 2:
    print('Usage: sendlongsms.py [configfile] RECIPIENT_NUMBER')
    sys.exit(1)

# Connect to the phone
state_machine.Init()


# Create SMS info structure
smsinfo = {
    'Class': -1,
    'Unicode': False,
    'Entries':  [
        {
            'ID': 'ConcatenatedTextLong',
            'Buffer':
                'Very long python-gammu testing message '
                'sent from example python script. '
                'Very long python-gammu testing message '
                'sent from example python script. '
                'Very long python-gammu testing message '
                'sent from example python script. '
        }
    ]}

# Encode messages
encoded = gammu.EncodeSMS(smsinfo)

# Send messages
for message in encoded:
    # Fill in numbers
    message['SMSC'] = {'Location': 1}
    message['Number'] = sys.argv[1]

    # Actually send the message
    state_machine.SendSMS(message)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import sys
import codecs


def main():
    if len(sys.argv) != 2:
        print('This requires parameter: backup file!')
        sys.exit(1)

    charsetencoder = codecs.getencoder(sys.getdefaultencoding())

    filename = sys.argv[1]

    backup = gammu.ReadSMSBackup(filename)

    # Make nested array
    messages = [[message] for message in backup]

    data = gammu.LinkSMS(messages)

    for message in data:
        decoded = gammu.DecodeSMS(message)

        part = message[0]
        print()
        print('{0:<15}: {1}'.format('Number', part['Number']))
        print('{0:<15}: {1}'.format('Date', str(part['DateTime'])))
        print('{0:<15}: {1}'.format('State', part['State']))
        print('{0:<15}: {1}'.format('Folder', part['Folder']))
        print('{0:<15}: {1}'.format('Validity', part['SMSC']['Validity']))
        loc = []
        for part in message:
            loc.append(str(part['Location']))
        print('{0:<15}: {1}'.format('Location(s)', ', '.join(loc)))
        if decoded is None:
            print('\n{0}'.format(charsetencoder(part['Text'], 'replace')[0]))
        else:
            for entries in decoded['Entries']:
                print()
                print('{0:<15}: {1}'.format('Type', entries['ID']))
                if entries['Bitmap'] is not None:
                    for bmp in entries['Bitmap']:
                        print('Bitmap:')
                        for row in bmp['XPM'][3:]:
                            print(row)
                    print()
                if entries['Buffer'] is not None:
                    print('Text:')
                    print(charsetencoder(entries['Buffer'], 'replace'))
                    print()

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""Sample script to show how to send SMS through SMSD"""

from __future__ import print_function
import gammu.smsd
import sys

smsd = gammu.smsd.SMSD('/etc/gammu-smsdrc')

if len(sys.argv) != 2:
    print('Usage: smsd-inject.py RECIPIENT_NUMBER')
    sys.exit(1)

message = {
    'Text': 'python-gammu testing message',
    'SMSC': {'Location': 1},
    'Number': sys.argv[1]
}

smsd.InjectSMS([message])



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
'''
python-gammu - Phone communication libary

Gammu asynchronous wrapper example. This allows your application to care
only about handling received data and not about phone communication
details.
'''

from __future__ import print_function
import sys
import gammu
import gammu.worker


def callback(name, result, error, percents):
    '''
    Callback which is executed when something is done. Please remember
    this is called from different thread so it does not have to be save
    to work with GUI here.
    '''
    print(
        '-> {0} completed {1:d}% with error {2} , return value:'.format(
            name,
            percents,
            error
        )
    )
    print(result)


def read_config():
    '''
    Reads gammu configuration.
    '''
    state_machine = gammu.StateMachine()
    # This is hack and should be as parameter of this function
    if len(sys.argv) == 2:
        state_machine.ReadConfig(Filename=sys.argv[1])
    else:
        state_machine.ReadConfig()
    return state_machine.GetConfig()


def main():
    '''
    Main code to talk with worker.
    '''
    worker = gammu.worker.GammuWorker(callback)
    worker.configure(read_config())
    # We can directly invoke commands
    worker.enqueue('GetManufacturer')
    worker.enqueue('GetSIMIMSI')
    worker.enqueue('GetIMEI')
    worker.enqueue('GetOriginalIMEI')
    worker.enqueue('GetManufactureMonth')
    worker.enqueue('GetProductCode')
    worker.enqueue('GetHardware')
    worker.enqueue('GetDateTime')
    # We can create compound tasks
    worker.enqueue('CustomGetInfo', commands=[
        'GetModel',
        'GetBatteryCharge'
        ])
    # We can pass parameters
    worker.enqueue('GetMemory', ('SM', 1))
    # We can create compound tasks with parameters:
    worker.enqueue('CustomGetAllMemory', commands=[
        ('GetMemory', ('SM', 1)),
        ('GetMemory', ('SM', 2)),
        ('GetMemory', ('SM', 3)),
        ('GetMemory', ('SM', 4)),
        ('GetMemory', ('SM', 5))
        ])
    print('All commands submitted')
    worker.initiate()
    print('Worker started')
    # We can also pass commands with named parameters
    worker.enqueue('GetSMSC', {'Location': 1})
    print('Submitted additional command')
    worker.terminate()
    print('Worker done')

if __name__ == '__main__':
    main()



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
import unittest
import gammu
import glob
import tempfile
import os
import os.path

TEST_DIR = os.path.join(os.path.dirname(__file__), 'data')
TEST_FILES_CALENDAR = (
    glob.glob(os.path.join(TEST_DIR, '*.ics')) +
    glob.glob(os.path.join(TEST_DIR, '*.vcs'))
)
TEST_FILES_CONTACTS = (
    glob.glob(os.path.join(TEST_DIR, '*.vcf'))
)
TEST_CONTACTS = ('.lmb', '.vcf', '.backup')
TEST_CALENDAR = ('.vcs', '.ics', '.backup')


class BackupTest(unittest.TestCase):
    def perform_test(self, filename, extensions):
        out_files = [
            tempfile.NamedTemporaryFile(suffix=extension, delete=False)
            for extension in extensions
        ]
        out_backup = tempfile.NamedTemporaryFile(
            suffix='.backup', delete=False
        )
        # Close all files (needed on Windows)
        for handle in out_files:
            handle.close()
        out_backup.close()
        try:
            backup = gammu.ReadBackup(filename)
            for out in out_files:
                # Save to new format
                gammu.SaveBackup(out.name, backup)

                # Parse created file
                backup_2 = gammu.ReadBackup(out.name)

                # Check content length
                self.assertEqual(
                    len(backup['Calendar']),
                    len(backup_2['Calendar']),
                    'Failed to compare calendar in {0}'.format(filename)
                )
                self.assertEqual(
                    len(backup['PhonePhonebook']) +
                    len(backup['SIMPhonebook']),
                    len(backup_2['PhonePhonebook']) +
                    len(backup_2['SIMPhonebook']),
                    'Failed to compare phonebook in {0}'.format(filename)
                )

                # Try converting to .backup
                gammu.SaveBackup(out_backup.name, backup)
        finally:
            for handle in out_files:
                os.unlink(handle.name)
            os.unlink(out_backup.name)

    def test_convert_contacts(self):
        for filename in TEST_FILES_CONTACTS:
            self.perform_test(filename, TEST_CONTACTS)

    def test_convert_calendar(self):
        for filename in TEST_FILES_CALENDAR:
            self.perform_test(filename, TEST_CALENDAR)

    def test_calendar(self):
        entry = gammu.ReadBackup(
            os.path.join(TEST_DIR, 'rrule.ics')
        )['Calendar'][0]

        # Convert it to vCard
        vc_entry = gammu.EncodeVCALENDAR(entry)
        ic_entry = gammu.EncodeICALENDAR(entry)

        # Convert it back to entry
        entry2 = gammu.DecodeVCS(vc_entry)
        entry3 = gammu.DecodeICS(ic_entry)

        self.assertEqual(entry2['Type'], entry3['Type'])

    def test_todo(self):
        entry = gammu.ReadBackup(
            os.path.join(TEST_DIR, '02.vcs')
        )['ToDo'][0]

        # Convert it to vCard
        vt_entry = gammu.EncodeVTODO(entry)
        it_entry = gammu.EncodeITODO(entry)

        # Convert it back to entry
        entry2 = gammu.DecodeVCS(vt_entry)
        entry3 = gammu.DecodeICS(it_entry)

        self.assertEqual(entry2['Type'], entry3['Type'])

    def test_contact(self):
        entry = gammu.ReadBackup(
            os.path.join(TEST_DIR, 'gammu.vcf')
        )['PhonePhonebook'][0]

        # Convert it to vCard
        vc_entry = gammu.EncodeVCARD(entry)

        # Convert it back to entry
        entry2 = gammu.DecodeVCARD(vc_entry)

        self.assertEqual(entry, entry2)



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
from __future__ import unicode_literals
import unittest
import gammu
import tempfile
import shutil
import datetime
import platform
import os.path

DUMMY_DIR = os.path.join(os.path.dirname(__file__), 'data', 'gammu-dummy')
TEST_FILE = os.path.join(os.path.dirname(__file__), 'data', 'sqlite-14.sql')
CONFIGURATION = '''
# Configuration for Gammu testsuite

[gammu]
model = dummy
connection = none
port = {path}/gammu-dummy
gammuloc = /dev/null
logformat = none

[smsd]
commtimeout = 1
debuglevel = 255
logfile = stderr
service = sql
driver = sqlite3
sql = sqlite
database = smsd.db
dbdir = {path}
'''


class DummyTest(unittest.TestCase):
    test_dir = None
    config_name = None
    dummy_dir = None
    _called = False
    _state_machine = None

    def setUp(self):
        self.test_dir = tempfile.mkdtemp()
        self.dummy_dir = os.path.join(self.test_dir, 'gammu-dummy')
        self.config_name = os.path.join(self.test_dir, '.gammurc')
        shutil.copytree(DUMMY_DIR, self.dummy_dir)
        with open(self.config_name, 'w') as handle:
            handle.write(CONFIGURATION.format(path=self.test_dir))

    def tearDown(self):
        if self._state_machine:
            self._state_machine.Terminate()
        shutil.rmtree(self.test_dir)

    def get_statemachine(self):
        state_machine = gammu.StateMachine()
        state_machine.ReadConfig(Filename=self.config_name)
        state_machine.Init()
        self._state_machine = state_machine
        return state_machine

    def fake_incoming_call(self):
        """Fake incoming call"""
        filename = os.path.join(self.dummy_dir, 'incoming-call')
        with open(filename, 'w') as handle:
            handle.write('\n')

    def check_incoming_call(self):
        """Checks whether incoming call faking is supported"""
        current = tuple([int(x) for x in gammu.Version()[2].split('.')])
        if current < (1, 37, 91):
            raise unittest.SkipTest(
                'Not supported in version {0}'.format(gammu.Version()[2])
            )

    def call_callback(self, state_machine, response, data):
        '''
        Callback on USSD data.
        '''
        self._called = True
        self.assertEqual(response, 'Call')
        self.assertEqual(data['Number'], '+800123456')


class BasicDummyTest(DummyTest):
    def test_model(self):
        state_machine = self.get_statemachine()
        self.assertEqual(state_machine.GetModel()[1], 'Dummy')

    def test_diverts(self):
        state_machine = self.get_statemachine()
        diverts = state_machine.GetCallDivert()
        self.assertEqual(
            diverts,
            [{
                'CallType': 'All',
                'Timeout': 0,
                'Number': '',
                'DivertType': 'AllTypes'
            }]
        )

        state_machine.SetCallDivert('AllTypes', 'All', '123456789')
        diverts = state_machine.GetCallDivert()
        self.assertEqual(
            diverts,
            [{
                'CallType': 'All',
                'Timeout': 0,
                'Number': '123456789',
                'DivertType': 'AllTypes'
            }]
        )

    def test_dial(self):
        state_machine = self.get_statemachine()
        state_machine.DialVoice('123456')

    def test_battery(self):
        state_machine = self.get_statemachine()
        status = state_machine.GetBatteryCharge()
        self.assertEqual(
            status,
            {
                'BatteryVoltage': 4200,
                'PhoneTemperature': 22,
                'BatteryTemperature': 22,
                'ChargeState': 'BatteryConnected',
                'ChargeVoltage': 4200,
                'BatteryCapacity': 2000,
                'BatteryPercent': 100,
                'ChargeCurrent': 0,
                'PhoneCurrent': 500
            }
        )

    def test_memory(self):
        state_machine = self.get_statemachine()
        status = state_machine.GetMemoryStatus(Type='ME')

        remain = status['Used']

        self.assertEqual(status['Used'], 3)

        start = True

        while remain > 0:
            if start:
                entry = state_machine.GetNextMemory(Start=True, Type='ME')
                start = False
            else:
                entry = state_machine.GetNextMemory(
                    Location=entry['Location'], Type='ME'
                )
            remain = remain - 1

    def test_getmemory(self):
        state_machine = self.get_statemachine()

        location = state_machine.AddMemory(
            {
                'MemoryType': 'SM',
                'Entries': [
                    {'Type': 'Number_Mobile', 'Value': '123456'},
                    {'Type': 'Text_Name', 'Value': 'Jmeno'},
                ]
            }
        )

        read = state_machine.GetMemory('SM', location)
        self.assertEqual(len(read['Entries']), 2)

    def test_calendar(self):
        state_machine = self.get_statemachine()
        status = state_machine.GetCalendarStatus()

        remain = status['Used']

        self.assertEqual(status['Used'], 2)

        start = True

        while remain > 0:
            if start:
                entry = state_machine.GetNextCalendar(Start=True)
                start = False
            else:
                entry = state_machine.GetNextCalendar(
                    Location=entry['Location']
                )
            remain = remain - 1

    def test_sms(self):
        state_machine = self.get_statemachine()
        status = state_machine.GetSMSStatus()

        remain = (
            status['SIMUsed'] +
            status['PhoneUsed'] +
            status['TemplatesUsed']
        )

        self.assertEqual(remain, 6)

        start = True

        sms = []

        while remain > 0:
            if start:
                sms.append(state_machine.GetNextSMS(Start=True, Folder=0))
                start = False
            else:
                sms.append(
                    state_machine.GetNextSMS(
                        Location=sms[-1][0]['Location'], Folder=0
                    )
                )
            remain = remain - len(sms)

        data = gammu.LinkSMS(sms)

        for item in data:
            message = gammu.DecodeSMS(item)
            if message is None:
                self.assertEqual(item[0]['UDH']['Type'], 'NoUDH')

    def test_todo(self):
        state_machine = self.get_statemachine()
        status = state_machine.GetToDoStatus()

        remain = status['Used']

        self.assertEqual(status['Used'], 2)

        start = True

        while remain > 0:
            if start:
                entry = state_machine.GetNextToDo(Start=True)
                start = False
            else:
                entry = state_machine.GetNextToDo(Location=entry['Location'])
            remain = remain - 1

    def test_sms_folders(self):
        state_machine = self.get_statemachine()
        folders = state_machine.GetSMSFolders()
        self.assertEqual(len(folders), 5)

    def ussd_callback(self, state_machine, response, data):
        '''
        Callback on USSD data.
        '''
        self._called = True
        self.assertEqual(response, 'USSD')
        self.assertEqual(data['Text'], 'Reply for 1234')
        self.assertEqual(data['Status'], 'NoActionNeeded')

    def test_ussd(self):
        self._called = False
        state_machine = self.get_statemachine()
        state_machine.SetIncomingCallback(self.ussd_callback)
        state_machine.SetIncomingUSSD()
        state_machine.DialService('1234')
        self.assertTrue(self._called)

    def test_sendsms(self):
        state_machine = self.get_statemachine()
        message = {
            'Text': 'python-gammu testing message',
            'SMSC': {'Location': 1},
            'Number': '123456',
        }

        state_machine.SendSMS(message)

    def test_sendsms_long(self):
        state_machine = self.get_statemachine()
        text = (
            'Very long python-gammu testing message sent '
            'from example python script. '
        ) * 10
        smsinfo = {
            'Class': -1,
            'Unicode': False,
            'Entries':  [
                {
                    'ID': 'ConcatenatedTextLong',
                    'Buffer': text
                }
            ]}

        # Encode messages
        encoded = gammu.EncodeSMS(smsinfo)

        self.assertEqual(len(encoded), 5)

        # Send messages
        for message in encoded:
            # Fill in numbers
            message['SMSC'] = {'Location': 1}
            message['Number'] = '123456'

            # Actually send the message
            state_machine.SendSMS(message)

    def test_filesystem(self):
        state_machine = self.get_statemachine()
        fs_info = state_machine.GetFileSystemStatus()
        self.assertEqual(
            fs_info,
            {
                'UsedImages': 0,
                'Used': 1000000,
                'UsedThemes': 0,
                'Free': 10101,
                'UsedSounds': 0
            }
        )

    def test_deletefile(self):
        state_machine = self.get_statemachine()
        self.assertRaises(
            gammu.ERR_FILENOTEXIST,
            state_machine.DeleteFile,
            'testfolder/nonexisting.png'
        )
        state_machine.DeleteFile('file5')

    def test_deletefolder(self):
        state_machine = self.get_statemachine()
        self.assertRaises(
            gammu.ERR_FILENOTEXIST,
            state_machine.DeleteFolder,
            'testfolder'
        )
        state_machine.AddFolder('', 'testfolder')
        state_machine.DeleteFolder('testfolder')

    @unittest.skipIf(platform.system() == 'Windows',
        'Not supported on Windows')
    def test_emoji_folder(self):
        state_machine = self.get_statemachine()
        name = 'test-😘'
        self.assertRaises(
            gammu.ERR_FILENOTEXIST,
            state_machine.DeleteFolder,
            name
        )
        self.assertEqual(
            name,
            state_machine.AddFolder('', name)
        )
        # Check the folder exists as expected on filesystem
        self.assertTrue(
            os.path.exists(os.path.join(self.dummy_dir, 'fs', name))
        )
        state_machine.DeleteFolder(name)

    def test_addfile(self):
        state_machine = self.get_statemachine()
        file_stat = os.stat(TEST_FILE)
        ttime = datetime.datetime.fromtimestamp(file_stat[8])
        with open(TEST_FILE, 'rb') as handle:
            content = handle.read()
        file_f = {
            "ID_FullName": 'testfolder',
            "Name": 'sqlite.sql',
            "Modified": ttime,
            "Folder": 0,
            "Level": 1,
            "Used": file_stat[6],
            "Buffer": content,
            "Type": "Other",
            "Protected": 0,
            "ReadOnly": 0,
            "Hidden": 0,
            "System": 0,
            "Handle": 0,
            "Pos": 0,
            "Finished": 0
        }
        state_machine.AddFolder('', 'testfolder')
        while not file_f["Finished"]:
            file_f = state_machine.AddFilePart(file_f)

    def test_fileattributes(self):
        state_machine = self.get_statemachine()
        state_machine.SetFileAttributes(
            'file5', ReadOnly=1, Protected=0, System=1, Hidden=1
        )

    def test_getnextfile(self):
        state_machine = self.get_statemachine()
        file_f = state_machine.GetNextFileFolder(1)
        folders = 0
        files = 0
        while 1:
            if file_f['Folder']:
                folders += 1
            else:
                files += 1
            try:
                file_f = state_machine.GetNextFileFolder(0)
            except gammu.ERR_EMPTY:
                break
        self.assertEqual(folders, 3)
        self.assertEqual(files, 6)

    def test_incoming_call(self):
        self.check_incoming_call()
        self._called = False
        state_machine = self.get_statemachine()
        state_machine.SetIncomingCallback(self.call_callback)
        state_machine.SetIncomingCall()
        state_machine.GetSignalQuality()
        self.fake_incoming_call()
        state_machine.GetSignalQuality()
        self.assertTrue(self._called)



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
from __future__ import print_function
from .test_dummy import DummyTest
import gammu.smsd
import os
import os.path
import threading
import time
import platform
import sqlite3
import unittest


MESSAGE_1 = {
    'Text': 'python-gammu testing message',
    'SMSC': {'Location': 1},
    'Number': '1234567890'
}
MESSAGE_2 = {
    'Text': 'python-gammu second testing message',
    'SMSC': {'Location': 1},
    'Number': '1234567890'
}


def get_script():
    """Returns SQL script to create database

    It returns correct script matching used Gammu version.
    """
    version = tuple(
        [int(x) for x in gammu.Version()[0].split('.')]
    )

    if version < (1, 36, 7):
        dbver = 14
    elif version < (1, 37, 90):
        dbver = 15
    elif version < (1, 38, 5):
        dbver = 16
    else:
        dbver = 17

    print('Gammu version {0}, SMSD DB version {1}'.format(version, dbver))

    return os.path.join(
        os.path.dirname(__file__),
        'data',
        'sqlite-{0}.sql'.format(dbver)
    )


class SMSDDummyTest(DummyTest):
    def setUp(self):
        if platform.system() == 'Windows':
            raise unittest.SkipTest('SMSD testing not supported on Windows (no DBI driver)')
        super(SMSDDummyTest, self).setUp()
        database = sqlite3.connect(
            os.path.join(self.test_dir, 'smsd.db')
        )
        with open(get_script(), 'r') as handle:
            database.executescript(handle.read())

    def get_smsd(self):
        return gammu.smsd.SMSD(self.config_name)

    def test_init_error(self):
        self.assertRaises(TypeError, gammu.smsd.SMSD, Bar=1)

    def test_inject(self):
        smsd = self.get_smsd()
        smsd.InjectSMS([MESSAGE_1])

    def test_smsd(self):
        smsd = self.get_smsd()

        # Inject SMS messages
        # Please note that SMSD is not thread safe, so you can not
        # use inject and main loop from different threads
        smsd.InjectSMS([MESSAGE_1])
        smsd.InjectSMS([MESSAGE_2])

        try:
            # Start SMSD thread
            smsd_thread = threading.Thread(target=smsd.MainLoop)
            smsd_thread.start()
            # We need to let it run for some time here to finish initialization
            time.sleep(10)

            # Show SMSD status
            retries = 0
            while retries < 2:
                status = smsd.GetStatus()
                if status['Sent'] >= 2:
                    break
                time.sleep(10)
                retries += 1

            self.assertEqual(
                status['Received'],
                2,
                'Messages were not received as expected ({0:d})!'.format(
                status['Received'])
            )
            self.assertEqual(
                status['Sent'],
                2,
                'Messages were not sent as expected ({0:d})!'.format(
                status['Sent'])
            )

            time.sleep(1)

        finally:
            # Signal SMSD to stop
            smsd.Shutdown()

            # Wait for it
            smsd_thread.join()



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
'''
SMSD wrapper layer.
'''
from gammu import SMSD

__all__ = ['SMSD']



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import time


def callback(state_machine, callback_type, data):
    '''
    This callback receives notification about incoming event.

    @param state_machine: state machine which invoked action
    @type state_machine: gammu.StateMachine
    @param callback_type: type of action, one of Call, SMS, CB, USSD
    @type callback_type: string
    @param data: event data
    @type data: hash
    '''
    print('Received incoming event type {0}, data:'.format(callback_type))
    print(data)


def try_enable(call, name):
    try:
        call()
    except gammu.ERR_NOTSUPPORTED:
        print('{0} notification is not supported.'.format(name))
    except gammu.ERR_SOURCENOTAVAILABLE:
        print('{0} notification is not enabled in Gammu.'.format(name))


def main():
    # Create state machine
    state_machine = gammu.StateMachine()
    # Read gammurc
    state_machine.ReadConfig()
    # Initialize state machine and connect to phone
    state_machine.Init()
    # Set callback handler for incoming notifications
    state_machine.SetIncomingCallback(callback)

    # Enable notifications from calls
    try_enable(state_machine.SetIncomingCall, 'Incoming calls')

    # Enable notifications from cell broadcast
    try_enable(state_machine.SetIncomingCB, 'Incoming cell broadcasts')

    # Enable notifications from incoming SMS
    try_enable(state_machine.SetIncomingSMS, 'Incoming SMS')

    # Enable notifications for incoming USSD
    try_enable(state_machine.SetIncomingUSSD, 'Incoming USSD')

    # Just a busy waiting for event
    # We need to keep communication with phone to get notifications
    print('Press Ctrl+C to interrupt')
    while 1:
        signal = state_machine.GetSignalQuality()
        print('Signal is at {0:d}%'.format(signal['SignalPercent']))
        time.sleep(1)

if __name__ == '__main__':
    main()



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
import unittest
import tempfile
import gammu
import os
from .test_sms import PDU_DATA


class ConfigTest(unittest.TestCase):
    def test_config_bool(self):
        state_machine = gammu.StateMachine()
        state_machine.SetConfig(
            0,
            {
                'StartInfo': True,
                'UseGlobalDebugFile': True,
                'DebugFile': None,
                'SyncTime': True,
                'Connection': 'at',
                'LockDevice': True,
                'DebugLevel': 'textalldate',
                'Device': '',
                'Model': '',
            },
        )
        cfg = state_machine.GetConfig(0)
        self.assertEqual(cfg['StartInfo'], 1)

    def test_config_string(self):
        state_machine = gammu.StateMachine()
        state_machine.SetConfig(
            0,
            {
                'StartInfo': 'yes',
                'UseGlobalDebugFile': 'no',
                'DebugFile': 'dbg.log',
                'SyncTime': 'true',
                'Connection': 'fbus',
                'LockDevice': 'FALSE',
                'DebugLevel': 'textall',
                'Device': '',
                'Model': '',
            },
        )
        cfg = state_machine.GetConfig(0)
        self.assertEqual(cfg['StartInfo'], 1)

    def test_config_none(self):
        state_machine = gammu.StateMachine()
        state_machine.SetConfig(
            0,
            {
                'StartInfo': None,
                'UseGlobalDebugFile': None,
                'DebugFile': 'dbg.log',
                'SyncTime': 'true',
                'Connection': 'dlr3',
                'LockDevice': 'NO',
                'DebugLevel': 'binary',
                'Device': '',
                'Model': '',
            },
        )
        cfg = state_machine.GetConfig(0)
        self.assertEqual(cfg['StartInfo'], 0)

    def test_init_error(self):
        self.assertRaises(TypeError, gammu.StateMachine, Bar=1)


class DebugTest(unittest.TestCase):
    def setUp(self):
        gammu.SetDebugLevel('textall')

    def check_operation(self, filename, handle=None):
        """
        Executes gammu operation which causes debug logs.
        """
        gammu.DecodePDU(PDU_DATA)
        gammu.SetDebugFile(None)
        if handle:
            handle.close()
        if filename is not None:
            with open(filename, 'r') as handle:
                self.assertTrue('SMS type: Status report' in handle.read())

    def test_file(self):
        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
        testfile.close()
        try:
            handle = open(testfile.name, 'w')
            gammu.SetDebugFile(handle)
            self.check_operation(testfile.name, handle)
        finally:
            gammu.SetDebugFile(None)
            os.unlink(testfile.name)

    def test_filename(self):
        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
        testfile.close()
        try:
            gammu.SetDebugFile(testfile.name)
            self.check_operation(testfile.name)
        finally:
            gammu.SetDebugFile(None)
            os.unlink(testfile.name)

    def test_none(self):
        gammu.SetDebugFile(None)
        self.check_operation(None)

    def test_nothing(self):
        gammu.SetDebugLevel('nothing')
        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
        testfile.close()
        try:
            gammu.SetDebugFile(testfile.name)
            self.check_operation(None)
            with open(testfile.name, 'r') as handle:
                self.assertEqual('', handle.read())
        finally:
            gammu.SetDebugFile(None)
            os.unlink(testfile.name)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
'''
Service numbers dialogue example.
'''

from __future__ import print_function
import gammu
import sys

REPLY = False


def callback(state_machine, callback_type, data):
    '''
    Callback on USSD data.
    '''
    global REPLY
    if callback_type != 'USSD':
        print('Unexpected event type: {0}'.format(callback_type))
        sys.exit(1)

    REPLY = True

    print('Network reply:')
    print('Status: {0}'.format(data['Status']))
    print(data['Text'])

    if data['Status'] == 'ActionNeeded':
        do_service(state_machine)


def init():
    '''
    Intializes gammu and callbacks.
    '''
    state_machine = gammu.StateMachine()
    if len(sys.argv) >= 2:
        state_machine.ReadConfig(Filename=sys.argv[1])
    else:
        state_machine.ReadConfig()
    state_machine.Init()
    state_machine.SetIncomingCallback(callback)
    try:
        state_machine.SetIncomingUSSD()
    except gammu.ERR_NOTSUPPORTED:
        print('Incoming USSD notification is not supported.')
        sys.exit(1)
    return state_machine


def do_service(state_machine):
    '''
    Main code to talk with worker.
    '''
    global REPLY

    if len(sys.argv) >= 3:
        code = sys.argv[2]
        del sys.argv[2]
    else:
        prompt = 'Enter code (empty string to end): '
        try:
            code = raw_input(prompt)
        except NameError:
            code = input(prompt)
    if code != '':
        print('Talking to network...')
        REPLY = False
        state_machine.DialService(code)
        loops = 0
        while not REPLY and loops < 10:
            state_machine.ReadDevice()
            loops += 1


def main():
    state_machine = init()
    print('This example shows interaction with network using service codes')
    do_service(state_machine)


if __name__ == '__main__':
    main()



# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
from __future__ import unicode_literals
import datetime
import unittest
import gammu
import sys
import os
import binascii

PDU_DATA = binascii.unhexlify(
    b'079124602009999002AB098106845688F8907080517375809070805183018000'
)

MESSAGE = (
    '.........1.........2.........3.........4.........5.........6.........7'
    '.........8.........9........0.........1.........2.........3.........4'
    '.........5.........6.........7.........8.........9........0.........1'
    '.........2.........3.........4.........5.........6.........7.........8'
    '.........9........0'
)
UNICODE = (
    '.........1ě........2..ř......3...žš....4....ý....5....á....6....á....7'
    '.........8.........9........0.........1.........2.........3.........4'
    '.........5.........6.........7.........8.........9........0.........1'
    '.........2.........3.........4.........5.........6.........7.........8'
    '.........9....č...0'
)
GSM = (
    '.........1$........2..Ø......3...åÅ....4....Λ....5....Æ....6....ñ....7'
    '.........8.........9........0.........1.........2.........3.........4'
    '.........5.........6.........7.........8.........9........0.........1'
    '.........2.........3.........4.........5.........6.........7.........8'
    '.........9....¥€..0'
)


class PDUTest(unittest.TestCase):
    def setUp(self):
        if 'GAMMU_DEBUG' in os.environ:
            gammu.SetDebugFile(sys.stderr)
            gammu.SetDebugLevel('textall')

    def test_decode(self):
        sms = gammu.DecodePDU(PDU_DATA)
        self.assertEqual(sms['Number'], '604865888')
        self.assertEqual(sms['Text'], 'Delivered')

    def do_smstest(self, smsinfo, expected):
        # encode SMSes
        sms = gammu.EncodeSMS(smsinfo)

        # decode back SMSes
        decodedsms = gammu.DecodeSMS(sms)

        # compare text
        self.assertEqual(decodedsms['Entries'][0]['Buffer'], expected)

        # do conversion to PDU
        pdu = [gammu.EncodePDU(s) for s in sms]

        # Convert back
        pdusms = [gammu.DecodePDU(p) for p in pdu]

        # decode back SMS from PDU
        decodedsms = gammu.DecodeSMS(pdusms)

        # compare PDU results
        self.assertEqual(decodedsms['Entries'][0]['Buffer'], expected)

    def test_encode_plain(self):
        smsinfo = {
            'Entries': [{'ID': 'ConcatenatedTextLong', 'Buffer': MESSAGE}]
        }
        self.do_smstest(smsinfo, MESSAGE)

    def test_encode_gsm(self):
        smsinfo = {
            'Entries': [{'ID': 'ConcatenatedTextLong', 'Buffer': GSM}]
        }
        self.do_smstest(smsinfo, GSM)

    def test_encode_unicode(self):
        smsinfo = {
            'Entries': [{'ID': 'ConcatenatedTextLong', 'Buffer': UNICODE}],
            'Unicode': True
        }
        self.do_smstest(smsinfo, UNICODE)

    def test_link(self):
        # SMS info about message
        smsinfo = {
            'Entries': [{'ID': 'ConcatenatedTextLong', 'Buffer': MESSAGE}]
        }

        # encode SMS
        sms = gammu.EncodeSMS(smsinfo)

        # link SMS
        linked = gammu.LinkSMS([[sms[0]], [sms[1]]], True)

        # decode back SMS
        decodedsms = gammu.DecodeSMS(linked[0])

        # compare results
        self.assertTrue(decodedsms['Entries'][0]['Buffer'], MESSAGE)

    def test_mms_decode(self):
        message = [{
            'RejectDuplicates': 0,
            'SMSCDateTime': datetime.datetime(2010, 7, 22, 17, 4, 11),
            'Class': -1,
            'Name': '',
            'InboxFolder': 0,
            'Text': (
                b'\x04\x06\x03\xbe\xaf\x84\x8c\x82\x981277970059\x00\x8d\x92'
                b'\x89\x19\x80\x16\x0433707520030/TYPE=PLMN\x00\x96yBO\x00'
                b'\x8a\x80\x8e\x01"\x88\x04\x81\x02\x0b\xb8\x83'
                b'http://mmsc.labmctel.fr:9090/m33\x00'
            ),
            'SMSC': {
                'DefaultNumber': '',
                'Format': 'Text',
                'Number': '+33700065030',
                'Validity': 'NA',
                'Location': 0,
                'Name': ''
            },
            'ReplaceMessage': 0,
            'Coding': '8bit',
            'Number': '33707520030',
            'DateTime': datetime.datetime(2010, 7, 1, 9, 40, 21),
            'DeliveryStatus': 0,
            'State': 'UnSent',
            'MessageReference': 0,
            'Length': 99,
            'Location': 0,
            'Memory': '',
            'ReplyViaSameSMSC': 0,
            'UDH': {
                'Text': b'\x06\x05\x04\x0b\x84#\xf0',
                'ID16bit': -1,
                'AllParts': -1,
                'ID8bit': -1,
                'PartNumber': -1,
                'Type': 'UserUDH'
            },
            'Type': 'Deliver',
            'Folder': 2
        }]

        decoded = gammu.DecodeSMS(message)
        self.assertEqual(
            decoded['Entries'][0]['MMSIndicator']['Address'],
            'http://mmsc.labmctel.fr:9090/m33'
        )

    def test_counter(self):
        self.assertEqual(
            gammu.SMSCounter('foobar'),
            (1, 154)
        )

    def test_counter_long(self):
        self.assertEqual(
            gammu.SMSCounter(
                'foobar fjsa;kjfkasdjfkljsklfjaskdljfkljasdfkljqilui143uu51o2'
                '3rjhskdf jasdklfjasdklf jasdfkljasdlkfj;asd;lfjaskdljf431ou9'
                '83jdfaskljfklsdjdkljasfl sdfjasdfkl jafklsda'
            ),
            (2, 156)
        )



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Matthias Blaesing <matthias.blaesing@rwth-aachen.de>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
Example for usage of GetNextFileFolder, which is oriented at

gammu --getfilesystem

Without argument you get a hierarchical list, provide flat as
argument and get somethink like (not exactly!)

gammu --getfilesystem -flatall
"""

from __future__ import print_function
import gammu
import locale
import argparse
parser = argparse.ArgumentParser(usage="usage: %(prog)s [options]")

parser.add_argument("-c", "--config",
                    action="store", type=str,
                    dest="config", default=None,
                    help="Config file path")
parser.add_argument("-f", "--flat",
                    action="store_true",
                    dest="flat", default=False,
                    help="Flat listing")
parser.add_argument("-l", "--level",
                    action="store_true",
                    dest="level", default=False,
                    help="Level listing")
args = parser.parse_args()

# Init gammu module
state_machine = gammu.StateMachine()
if args.config is not None:
    state_machine.ReadConfig(Filename=args.config)
else:
    state_machine.ReadConfig()
state_machine.Init()

# Get wished listing from commandline (if provided - else asume level)
# On commandline level or flat can be provided as parameters
if args.flat:
    mode = "flat"
else:
    mode = "level"

# Set locale to default locale (here relevant for printing of date)
locale.setlocale(locale.LC_ALL, '')


# Wrapper around GetNextFileFolder, catching gammu.ERR_EMPTY
# for me, which should be after the last entry and returning "None"
#
# GetNextFileFolder gives us a dict with:
# 'Name' => Symbolic Name of the file (String)
# 'ID_FullName' => unique ID of the file (String)
# 'Used' => space used in bytes (integer)
# 'Modified' => Date of last change (datetime)
# 'Type' => Filetype as reported by phone (String)
# 'Folder' => Entry is a Folder (Bool)
# 'Level' => On which level of FS (Integer)
# 'Buffer' => ?? (String)
# File Attributes (Bool):
# 'Protected'
# 'ReadOnly'
# 'Hidden'
# 'System'
def NextFile(start=0):
    try:
        return state_machine.GetNextFileFolder(start)
    except gammu.ERR_EMPTY:
        return None


# Format File Attributes as String as a shorted Version
def FileToAttributeString(file_obj, filled=1):
    protected = readonly = hidden = system = ""
    if filled:
        protected = readonly = hidden = system = u" "
    if file_obj["Protected"]:
        protected = u"P"
    if file_obj["ReadOnly"]:
        readonly = u"R"
    if file_obj["Hidden"]:
        hidden = u"H"
    if file_obj["System"]:
        system = u"S"
    return protected + readonly + hidden + system


def Main():
    # Make sure we reset the pointer of the current entry to the first
    file_obj = NextFile(1)

    # Iterate over Files and print the Info
    while file_obj:
        if mode == "flat":
            # Output:
            # <ID>;<NAME>;<TYPE>;<MODDATE>;<SIZE>;<ATTRIBUTES>
            # We have to catch the situations, where no Modification Time is
            # provided
            try:
                time = file_obj["Modified"].strftime("%x %X") + ";"
            except AttributeError:
                time = ";"

            print((
                file_obj["ID_FullName"] + ";" +
                file_obj["Name"] + ";" +
                file_obj["Type"] + ";" +
                time + str(file_obj["Used"]) + ";" +
                FileToAttributeString(file_obj, 0)
            ))
        elif mode == "level":
            attrib = FileToAttributeString(file_obj, 1)
            level = file_obj["Level"]

            spacer = " |   " * (level - 2)

            if level > 1:
                spacer += " |-- "

            title = '"' + file_obj["Name"] + '"'
            if file_obj["Folder"]:
                title = "Folder " + title
            print(attrib + spacer + title)
        file_obj = NextFile()


if __name__ == '__main__':
    Main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import sys


def main():
    if len(sys.argv) != 3:
        print(
            'This requires two parameters: '
            'memory_type and backup file (eg. vcard)!'
        )
        sys.exit(1)

    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()

    memory = sys.argv[1]
    filename = sys.argv[2]

    backup = gammu.ReadBackup(filename)

    for item in backup['PhonePhonebook']:
        item['MemoryType'] = memory
        loc = state_machine.AddMemory(item)
        print(('Added item to location {0:d}'.format(loc)))


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
'''
python-gammu - Test script to test several Gammu operations
(usually using dummy driver, but it depends on config)
'''

from __future__ import print_function
import gammu
import sys


def get_all_memory(state_machine, memory_type):
    status = state_machine.GetMemoryStatus(Type=memory_type)

    remain = status['Used']

    start = True

    while remain > 0:
        if start:
            entry = state_machine.GetNextMemory(Start=True, Type=memory_type)
            start = False
        else:
            entry = state_machine.GetNextMemory(
                Location=entry['Location'], Type=memory_type
            )
        remain = remain - 1

        print()
        print(('{0:<15}: {1:d}'.format('Location', entry['Location'])))
        for v in entry['Entries']:
            if v['Type'] in ('Photo'):
                print(('{0:<15}: {1}...'.format(v['Type'], repr(v['Value'])[:30])))
            else:
                print((
                    '{0:<15}: {1}'.format(v['Type'], str(v['Value']).encode('utf-8'))
                ))


def get_all_calendar(state_machine):
    status = state_machine.GetCalendarStatus()

    remain = status['Used']

    start = True

    while remain > 0:
        if start:
            entry = state_machine.GetNextCalendar(Start=True)
            start = False
        else:
            entry = state_machine.GetNextCalendar(Location=entry['Location'])
        remain = remain - 1

        print()
        print(('{0:<20}: {1:d}'.format('Location', entry['Location'])))
        print(('{0:<20}: {1}'.format('Type', entry['Type'])))
        for v in entry['Entries']:
            print(('{0:<20}: {1}'.format(v['Type'], str(v['Value']).encode('utf-8'))))


def get_battery_status(state_machine):
    status = state_machine.GetBatteryCharge()

    for x in status:
        if status[x] != -1:
            print(("{0:20}: {1}".format(x, status[x])))


def get_all_sms(state_machine):
    status = state_machine.GetSMSStatus()

    remain = status['SIMUsed'] + status['PhoneUsed'] + status['TemplatesUsed']

    start = True

    while remain > 0:
        if start:
            sms = state_machine.GetNextSMS(Start=True, Folder=0)
            start = False
        else:
            sms = state_machine.GetNextSMS(
                Location=sms[0]['Location'], Folder=0
            )
        remain = remain - len(sms)

    return sms


def print_sms_header(message, folders):
    print()
    print('{0:<15}: {1}'.format('Number', message['Number'].encode('utf-8')))
    print('{0:<15}: {1}'.format('Date', str(message['DateTime'])))
    print('{0:<15}: {1}'.format('State', message['State']))
    print('{0:<15}: {1} {2} ({3:d})'.format(
        'Folder',
        folders[message['Folder']]['Name'].encode('utf-8'),
        folders[message['Folder']]['Memory'].encode('utf-8'),
        message['Folder']
    ))
    print('{0:<15}: {1}'.format('Validity', message['SMSC']['Validity']))


def print_all_sms(sms, folders):
    for m in sms:
        print_sms_header(m, folders)
        print('\n{0}'.format(m['Text'].encode('utf-8')))


def link_all_sms(sms, folders):
    data = gammu.LinkSMS([[msg] for msg in sms])

    for x in data:
        v = gammu.DecodeSMS(x)

        m = x[0]
        print_sms_header(m, folders)
        loc = []
        for m in x:
            loc.append(str(m['Location']))
        print('{0:<15}: {1}'.format('Location(s)', ', '.join(loc)))
        if v is None:
            print('\n{0}'.format(m['Text'].encode('utf-8')))
        else:
            for e in v['Entries']:
                print()
                print('{0:<15}: {1}'.format('Type', e['ID']))
                if e['Bitmap'] is not None:
                    for bmp in e['Bitmap']:
                        print('Bitmap:')
                        for row in bmp['XPM'][3:]:
                            print(row)
                    print()
                if e['Buffer'] is not None:
                    print('Text:')
                    print(e['Buffer'].encode('utf-8'))
                    print()


def get_all_todo(state_machine):
    status = state_machine.GetToDoStatus()

    remain = status['Used']

    start = True

    while remain > 0:
        if start:
            entry = state_machine.GetNextToDo(Start=True)
            start = False
        else:
            entry = state_machine.GetNextToDo(Location=entry['Location'])
        remain = remain - 1

        print()
        print('{0:<15}: {1:d}'.format('Location', entry['Location']))
        print('{0:<15}: {1}'.format('Priority', entry['Priority']))
        for v in entry['Entries']:
            print('{0:<15}: {1}'.format(v['Type'], str(v['Value']).encode('utf-8')))


def get_sms_folders(state_machine):
    folders = state_machine.GetSMSFolders()
    for i, folder in enumerate(folders):
        print('Folder {0:d}: {1} ({2})'.format(
            i,
            folder['Name'].encode('utf-8'),
            folder['Memory'].encode('utf-8')
        ))
    return folders


def get_set_date_time(state_machine):
    dt = state_machine.GetDateTime()
    print(dt)
    state_machine.SetDateTime(dt)
    return dt


def main():
    if len(sys.argv) != 2:
        print('This requires one parameter with location of config file!')
        sys.exit(1)

    state_machine = gammu.StateMachine()
    state_machine.ReadConfig(Filename=sys.argv[1])
    state_machine.Init()
    smsfolders = get_sms_folders(state_machine)
    get_all_memory(state_machine, 'ME')
    get_all_memory(state_machine, 'SM')
    get_all_memory(state_machine, 'MC')
    get_all_memory(state_machine, 'RC')
    get_all_memory(state_machine, 'DC')
    get_battery_status(state_machine)
    get_all_calendar(state_machine)
    get_all_todo(state_machine)
    smslist = get_all_sms(state_machine)
    print_all_sms(smslist, smsfolders)
    link_all_sms(smslist, smsfolders)
    get_set_date_time(state_machine)

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import sys


def main():
    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()

    if len(sys.argv) != 2:
        print('This requires one parameter with memory type!')
        sys.exit(1)

    memory_type = sys.argv[1]

    status = state_machine.GetMemoryStatus(Type=memory_type)

    remain = status['Used']

    location = 1

    while remain > 0:
        try:
            entry = state_machine.GetMemory(Type=memory_type, Location=location)
            print()
            print('{0:<15}: {1:d}'.format('Location', entry['Location']))
            for v in entry['Entries']:
                print('{0:<15}: {1}'.format(v['Type'], str(v['Value'])))
            remain = remain - 1
        except gammu.ERR_EMPTY:
            pass
        location = location + 1


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import sys


def main():
    # Global debug level
    gammu.SetDebugFile(sys.stderr)
    gammu.SetDebugLevel('textall')

    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()

    # Use global debug stub regardless configuration
    c = state_machine.GetConfig(0)
    c['UseGlobalDebugFile'] = True
    state_machine.SetConfig(0, c)

    state_machine.Init()

    manufacturer = state_machine.GetManufacturer()
    model = state_machine.GetModel()
    imei = state_machine.GetIMEI()
    firmware = state_machine.GetFirmware()
    print('Phone infomation:')
    print(('{0:<15}: {1}'.format('Manufacturer', manufacturer)))
    print(('{0:<15}: {1} ({2})'.format('Model', model[0], model[1])))
    print(('{0:<15}: {1}'.format('IMEI', imei)))
    print(('{0:<15}: {1}'.format('Firmware', firmware[0])))


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""Example for reading calendar from phone"""

from __future__ import print_function
import gammu

# Create object for talking with phone
state_machine = gammu.StateMachine()

# Read the configuration (~/.gammurc)
state_machine.ReadConfig()

# Connect to the phone
state_machine.Init()

# Get number of calendar entries
status = state_machine.GetCalendarStatus()

remain = status['Used']

start = True

while remain > 0:
    # Read the entry
    if start:
        entry = state_machine.GetNextCalendar(Start=True)
        start = False
    else:
        entry = state_machine.GetNextCalendar(Location=entry['Location'])
    remain = remain - 1

    # Display it
    print()
    print('{0:<20}: {1:d}'.format('Location', entry['Location']))
    print('{0:<20}: {1}'.format('Type', entry['Type']))
    for v in entry['Entries']:
        print('{0:<20}: {1}'.format(v['Type'], str(v['Value'])))



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
'''
python-gammu - Phone communication libary
'''

from __future__ import print_function

from distutils.version import StrictVersion
import codecs
import glob
import os
import platform
from setuptools import setup, Extension
import subprocess
import sys

# some defines
VERSION = '2.12'
GAMMU_REQUIRED = '1.37.90'
README_FILE = os.path.join(os.path.dirname(__file__), 'README.rst')
with codecs.open(README_FILE, 'r', 'utf-8') as readme:
    README = readme.read()


class GammuConfig(object):
    def __init__(self):
        self.on_windows = platform.system() == 'Windows'
        self.has_pkgconfig = self.check_pkconfig()
        self.has_env = 'GAMMU_PATH' in os.environ
        self.path = self.lookup_path()
        self.use_pkgconfig = self.has_pkgconfig and not self.has_env

    def check_pkconfig(self):
        try:
            subprocess.check_output(['pkg-config', '--help'])
            return True
        except (subprocess.CalledProcessError, EnvironmentError):
            return False

    def config_path(self, base):
        return os.path.join(base, 'include', 'gammu', 'gammu-config.h')

    def lookup_path(self):
        if self.has_env:
            paths = [os.environ['GAMMU_PATH']]
        elif self.on_windows:
            paths = [
                'C:\\Gammu',
                'C:\\Program Files\\Gammu',
                'C:\\Program Files (x86)\\Gammu',
            ]
            paths += glob.glob('C:\\Program Files\\Gammu*')
            paths += glob.glob('C:\\Program Files (x86)\\Gammu*')
        else:
            paths = ['/usr/local/', '/usr/']
            paths += glob.glob('/opt/gammu*')

        for path in paths:
            include = self.config_path(path)
            if os.path.exists(include):
                return path

    def check_version(self):
        if self.use_pkgconfig:
            try:
                subprocess.check_output([
                    'pkg-config',
                    "--print-errors",
                    "--atleast-version={0}".format(GAMMU_REQUIRED),
                    "gammu",
                    "gammu-smsd"
                ])
                return
            except subprocess.CalledProcessError:
                print('Can not find supported Gammu version using pkg-config!')
                sys.exit(100)

        if self.path is None:
            print('Failed to find Gammu!')
            print('Either it is not installed or not found.')
            print('After install Gammu ensure that setup finds it by any of:')
            print(' * Specify path to it using GAMMU_PATH in environment.')
            print(' * Install pkg-config.')
            sys.exit(101)

        version = None
        with open(self.config_path(self.path), 'r') as handle:
            for line in handle:
                if line.startswith('#define GAMMU_VERSION '):
                    version = line.split('"')[1]

        if (version is None or
                StrictVersion(version) < StrictVersion(GAMMU_REQUIRED)):
            print('Too old Gammu version, please upgrade!')
            sys.exit(100)

    def get_libs(self):
        if self.use_pkgconfig:
            output = subprocess.check_output([
                'pkg-config', '--libs-only-l', 'gammu', 'gammu-smsd'
            ]).decode('utf-8')
            return output.replace('-l', '').strip().split()
        libs = ['Gammu', 'gsmsd']
        if self.on_windows:
            libs.append('Advapi32')
            libs.append('shfolder')
            libs.append('shell32')
        else:
            libs.append('m')
        return libs

    def get_cflags(self):
        if self.use_pkgconfig:
            return subprocess.check_output([
                'pkg-config', '--cflags', 'gammu', 'gammu-smsd'
            ]).decode('utf-8').strip()
        return '-I{0}'.format(
            os.path.join(self.path, 'include', 'gammu')
        )

    def get_ldflags(self):
        if self.use_pkgconfig:
            return subprocess.check_output([
                'pkg-config', '--libs-only-L', 'gammu', 'gammu-smsd'
            ]).decode('utf-8').strip()
        elif self.on_windows:
            return '/LIBPATH:{0}'.format(
                os.path.join(self.path, 'lib')
            )
        return '-L{0}'.format(
            os.path.join(self.path, 'lib')
        )


def get_module():
    config = GammuConfig()
    config.check_version()

    module = Extension(
        'gammu._gammu',
        define_macros=[
            ('PYTHON_GAMMU_MAJOR_VERSION', VERSION.split('.')[0]),
            ('PYTHON_GAMMU_MINOR_VERSION', VERSION.split('.')[1]),
        ],
        libraries=config.get_libs(),
        include_dirs=['include/'],
        sources=[
            'gammu/src/errors.c',
            'gammu/src/data.c',
            'gammu/src/misc.c',
            'gammu/src/convertors/misc.c',
            'gammu/src/convertors/string.c',
            'gammu/src/convertors/time.c',
            'gammu/src/convertors/base.c',
            'gammu/src/convertors/sms.c',
            'gammu/src/convertors/memory.c',
            'gammu/src/convertors/todo.c',
            'gammu/src/convertors/calendar.c',
            'gammu/src/convertors/bitmap.c',
            'gammu/src/convertors/ringtone.c',
            'gammu/src/convertors/backup.c',
            'gammu/src/convertors/file.c',
            'gammu/src/convertors/call.c',
            'gammu/src/convertors/wap.c',
            'gammu/src/convertors/diverts.c',
            'gammu/src/gammu.c',
            'gammu/src/smsd.c',
        ]
    )
    flags = config.get_cflags()
    if flags:
        module.extra_compile_args.append(flags)
    flags = config.get_ldflags()
    if flags:
        module.extra_link_args.append(flags)
    return module


setup(
    name='python-gammu',
    version=VERSION,
    description='Gammu bindings',
    long_description=README,
    author='Michal Cihar',
    author_email='michal@cihar.com',
    platforms=['Linux', 'Mac OSX', 'Windows XP/2000/NT', 'Windows 95/98/ME'],
    keywords=[
        'mobile', 'phone', 'SMS', 'contact', 'gammu', 'calendar', 'todo'
    ],
    license='GPLv2+',
    url='https://wammu.eu/python-gammu/',
    download_url='https://wammu.eu/download/python-gammu/',
    classifiers=[
        'Development Status :: 6 - Mature',
        'Intended Audience :: Developers',
        'Intended Audience :: Telecommunications Industry',
        'License :: OSI Approved :: '
        'GNU General Public License v2 or later (GPLv2+)',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: C',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Communications :: Telephony',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Hardware',
    ],
    test_suite="test",
    packages=['gammu'],
    ext_modules=[get_module()]
)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu


def main():
    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()

    status = state_machine.GetSMSStatus()

    remain = status['SIMUsed'] + status['PhoneUsed'] + status['TemplatesUsed']

    start = True

    try:
        while remain > 0:
            if start:
                sms = state_machine.GetNextSMS(Start=True, Folder=0)
                start = False
            else:
                sms = state_machine.GetNextSMS(
                    Location=sms[0]['Location'], Folder=0
                )
            remain = remain - len(sms)

            for m in sms:
                print()
                print('{0:<15}: {1}'.format('Number', m['Number']))
                print('{0:<15}: {1}'.format('Date', str(m['DateTime'])))
                print('{0:<15}: {1}'.format('State', m['State']))
                print('\n{0}'.format(m['Text']))
    except gammu.ERR_EMPTY:
        # This error is raised when we've reached last entry
        # It can happen when reported status does not match real counts
        print('Failed to read all messages!')


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu
import os
import sys


def main():
    if len(sys.argv) != 3:
        print('This requires two parameters: file to upload and path!')
        sys.exit(1)

    with open(sys.argv[1], 'rb') as handle:
        data = handle.read()

    state_machine = gammu.StateMachine()
    state_machine.ReadConfig()
    state_machine.Init()

    # Check AddFilePart
    print("\n\nExpection: Put specified file onto Memorycard on phone")
    file_f = {
        "ID_FullName": sys.argv[2],
        "Name": os.path.basename(sys.argv[1]),
        "Buffer": data,
        "Protected": 0,
        "ReadOnly": 0,
        "Hidden": 0,
        "System": 0,
        'Finished': 0,
        'Folder': 0,
        'Level': 0,
        'Type': 'Other',
        "Pos": 0,
    }

    while not file_f['Finished']:
        file_f = state_machine.AddFilePart(file_f)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
"""
Example for reading data from phone and convering it to and from
vCard, vTodo, vCalendar
"""

from __future__ import print_function
import gammu
import sys


def main():
    state_machine = gammu.StateMachine()
    if len(sys.argv) == 2:
        state_machine.ReadConfig(Filename=sys.argv[1])
    else:
        state_machine.ReadConfig()
    state_machine.Init()

    # For calendar entry

    # Read entry from phone
    entry = state_machine.GetNextCalendar(Start=True)

    # Convert it to vCard
    vc_entry = gammu.EncodeVCALENDAR(entry)
    ic_entry = gammu.EncodeICALENDAR(entry)

    # Convert it back to entry
    print(gammu.DecodeVCS(vc_entry))
    print(gammu.DecodeICS(ic_entry))

    # For todo entry

    # Read entry from phone
    entry = state_machine.GetNextToDo(Start=True)

    # Convert it to vCard
    vt_entry = gammu.EncodeVTODO(entry)
    it_entry = gammu.EncodeITODO(entry)

    # Convert it back to entry
    print(gammu.DecodeVCS(vt_entry))
    print(gammu.DecodeICS(it_entry))

    # For memory entry

    # Read entry from phone
    entry = state_machine.GetNextMemory(Start=True, Type='ME')

    # Convert it to vCard
    vc_entry = gammu.EncodeVCARD(entry)

    # Convert it back to entry
    print(gammu.DecodeVCARD(vc_entry))


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# vim: expandtab sw=4 ts=4 sts=4:
#
# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
#
# This file is part of python-gammu <https://wammu.eu/python-gammu/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

from __future__ import print_function
import gammu

state_machine = gammu.StateMachine()
state_machine.ReadConfig()
state_machine.Init()

status = state_machine.GetSMSStatus()

remain = status['SIMUsed'] + status['PhoneUsed'] + status['TemplatesUsed']

sms = []
start = True

try:
    while remain > 0:
        if start:
            cursms = state_machine.GetNextSMS(Start=True, Folder=0)
            start = False
        else:
            cursms = state_machine.GetNextSMS(
                Location=cursms[0]['Location'], Folder=0
            )
        remain = remain - len(cursms)
        sms.append(cursms)
except gammu.ERR_EMPTY:
    # This error is raised when we've reached last entry
    # It can happen when reported status does not match real counts
    print('Failed to read all messages!')

data = gammu.LinkSMS(sms)

for x in data:
    v = gammu.DecodeSMS(x)

    m = x[0]
    print()
    print('{0:<15}: {1}'.format('Number', m['Number']))
    print('{0:<15}: {1}'.format('Date', str(m['DateTime'])))
    print('{0:<15}: {1}'.format('State', m['State']))
    print('{0:<15}: {1}'.format('Folder', m['Folder']))
    print('{0:<15}: {1}'.format('Validity', m['SMSC']['Validity']))
    loc = []
    for m in x:
        loc.append(str(m['Location']))
    print('{0:<15}: {1}'.format('Location(s)', ', '.join(loc)))
    if v is None:
        print('\n{0}'.format(m['Text']))
    else:
        for e in v['Entries']:
            print()
            print('{0:<15}: {1}'.format('Type', e['ID']))
            if e['Bitmap'] is not None:
                for bmp in e['Bitmap']:
                    print('Bitmap:')
                    for row in bmp['XPM'][3:]:
                        print(row)
                print()
            if e['Buffer'] is not None:
                print('Text:')
                print(e['Buffer'])
                print()
